==> github-widget2-1.0.0.tgz: package/lib/App.test.js <==
'use strict';

var _jsxFileName = '../../src/App.test.jsx'; /* eslint-disable import/extensions */

var _reduxPromiseMiddleware = require('redux-promise-middleware');

var _reduxPromiseMiddleware2 = _interopRequireDefault(_reduxPromiseMiddleware);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _reduxMockStore = require('redux-mock-store');

var _reduxMockStore2 = _interopRequireDefault(_reduxMockStore);

var _reduxThunk = require('redux-thunk');

var _reduxThunk2 = _interopRequireDefault(_reduxThunk);

var _reactRedux = require('react-redux');

var _Api = require('./utils/Api');

var _Api2 = _interopRequireDefault(_Api);

var _App = require('./App.jsx');

var _App2 = _interopRequireDefault(_App);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var middleware = [(0, _reduxPromiseMiddleware2.default)(), _reduxThunk2.default.withExtraArgument({ GITHUB_API: _Api2.default })];
var mockStore = (0, _reduxMockStore2.default)(middleware);
describe('App component', function () {
  it('should render a component with props as specified ', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(
      _reactRedux.Provider,
      { store: mockStore({}), __source: {
          fileName: _jsxFileName,
          lineNumber: 17
        },
        __self: undefined
      },
      _react2.default.createElement(_App2.default, {
        __source: {
          fileName: _jsxFileName,
          lineNumber: 18
        },
        __self: undefined
      })
    ));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });
});

==> github-widget2-1.0.4.tgz: package/lib/App.test.js <==
'use strict';

var _reduxPromiseMiddleware = require('redux-promise-middleware');

var _reduxPromiseMiddleware2 = _interopRequireDefault(_reduxPromiseMiddleware);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _reduxMockStore = require('redux-mock-store');

var _reduxMockStore2 = _interopRequireDefault(_reduxMockStore);

var _reduxThunk = require('redux-thunk');

var _reduxThunk2 = _interopRequireDefault(_reduxThunk);

var _reactRedux = require('react-redux');

var _Api = require('./utils/Api');

var _Api2 = _interopRequireDefault(_Api);

var _App = require('./App.jsx');

var _App2 = _interopRequireDefault(_App);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var middleware = [(0, _reduxPromiseMiddleware2.default)(), _reduxThunk2.default.withExtraArgument({ GITHUB_API: _Api2.default })]; /* eslint-disable import/extensions */

var mockStore = (0, _reduxMockStore2.default)(middleware);
describe('App component', function () {
  it('should render a component with props as specified ', function () {
    var component = (0, _enzyme.shallow)(_react2.default.createElement(
      _reactRedux.Provider,
      { store: mockStore({}) },
      _react2.default.createElement(_App2.default, null)
    ));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });
});
